@@ -4,6 +4,9 @@ import subprocess
 
 __author__ = 'jbean'
 
+logger = logging.getLogger(name='root')
+
+
 class CommandError(Exception):
     pass
 
@@ -17,11 +20,11 @@ def assert_command(command):
     @type command: str
     @raise CommandError
     """
-    logging.debug('Command given: {}'.format(command))
+    logger.debug('Command given: {}'.format(command))
     child = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE)
     (stdoutdata, stderrdata) = child.communicate()
-    logging.debug('Out:  {}'.format(stdoutdata))
-    logging.debug('Err:  {}'.format(stderrdata))
+    logger.debug('Out:  {}'.format(stdoutdata))
+    logger.debug('Err:  {}'.format(stderrdata))
     if child.returncode:
         raise CommandError('Command failed with exit status {}'.format(child.returncode))
-    logging.debug('Finished running command.')
\ No newline at end of file
+    logger.debug('Finished running command.')
\ No newline at end of file
